#
# spec file for package gnome-firmware
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-firmware
Version:        43.1
Release:        1.4
Summary:        Install firmware on devices
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://gitlab.gnome.org/World/gnome-firmware
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  help2man
BuildRequires:  meson >= 0.46.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fwupd) >= 1.7.5
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4) >= 4.2
BuildRequires:  pkgconfig(libadwaita-1) >= 1.0.0
BuildRequires:  pkgconfig(xmlb) >= 0.1.7
Provides:       gnome-firmware-updater = %{version}-%{release}
Obsoletes:      gnome-firmware-updater < %{version}-%{release}
Provides:       gnome-firmware-updater-lang = %{version}-%{release}
Obsoletes:      gnome-firmware-updater-lang < %{version}-%{release}
%lang_package

%description
This application can update, reinstall and downgrade firmware on devices
supported by fwupd.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r -G "Install firmware on devices" org.gnome.Firmware "GTK;GNOME;Settings;HardwareSettings;"

%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/gnome-firmware
%{_datadir}/applications/org.gnome.Firmware.desktop
%{_datadir}/metainfo/org.gnome.Firmware.metainfo.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Firmware.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Firmware-symbolic.svg
%{_mandir}/man1/gnome-firmware.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Dec 29 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.1:
  + Add GPU symbol.
  + Change layout of GUIDs from PreferenceGroup to ExpanderRow.
  + Fix compile failure with -Dsystemd=false.
  + Updated translations.
* Fri Sep 16 2022 dead_mozay@opensuse.org
- Update to version 43.0:
  + Use the new usb-receiver icon.
  + Add a Windows msys2 build for future use.
  + Updated translations.
- Update _service and URL to new home.
* Tue May 31 2022 dimstar@opensuse.org
- Update to version 42.2:
  + Show device problems.
  + Verify without blocking the UI mainloop.
  + icons: provide generic device fallbacks.
  + Provide specific device icons and install as resources.
  + Show the About dialog in the menu.
  + icons: udate symbolic icon.
  + Do not show the estimated time to completion.
  + Use a revealer for the progress bar.
  + Don't pass user_data to window_destroy response cb.
  + Lower the GTK4 dep to build on F35.
- Changes from version 42.1:
  + Update the progressbar text for every percentage changed event.
  + Do not show crazy remaining time values.
  + Do not create a fake FwupdRequest as we set FLAG_REQUESTS.
  + Show how GUIDs are constructed in the UI.
  + Marks the application as adaptive in mobile in Phosh.
  + Show the 'No Releases Available' in more cases.
- Changes from version 42.0:
  + Use a GtkProgressBar for install progress.
  + Rate limit device refresh callbacks.
  + Allow the GUIDs to wrap when required.
  + Add the device branch to the device page.
  + Add some padding to the bottom of the page.
  + Move the release icon to right aligned.
  + Port to GTK4.
  + Allow installing firmware with FWUPD_DEVICE_FLAG_AFFECTS_FDE.
  + Updated translation.
- Replace pkgconfig(gtk+-3.0) BuildRequires with pkgconfig(gtk4):
  follow upstreams port to GTK4.
- Add pkgconfig(libadwaita-1) BuildRequires: new dependency.
- Drop gobject-introspection, perl-forks,
  pkgconfig(appstream-glib), pkgconfig(libsoup-2.4), and
  pkgconfig(systemd) buildRequires: no longer needed.
* Fri Jul  3 2020 Dead Mozay <dead_mozay@opensuse.org>
- Removed do-not-call-gtk_init-manually.patch. Fixed upstream
* Fri Jul  3 2020 dead_mozay@opensuse.org
- Update to version 3.36.0:
  * Dynamically show verify and releases buttons
  * Show device and progress when doing updates
  * Add Croatian translation
  * l10n: Add Turkish translation
  * l10n: Add Italian translation
* Wed Jan 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Fri Sep 20 2019 ecsos@opensuse.org
- Minimum required fwupd version is 1.2.10
* Tue Sep 17 2019 bjorn.lie@gmail.com
- Tweak _service file.
* Mon Sep 16 2019 dead_mozay@opensuse.org
- Update to version 3.34.0:
  * Use the project name of GNOME Firmware
  * Add a rough application icon
  * Build a man page for the Fedora package
  * Bump the version to match the GNOME release schedule
  * trivial: Make the device and firmware labels selectable
  * trivial: Make the GUID value monospace
  * trivial: Use sentence case in the main UI
  * Show more information and devices in the UI
  * trivial: Fix a logic thinko when displaying checksum hashes
* Thu Sep 12 2019 dead_mozay@opensuse.org
- Update to version 0.0.1~git.20190911:
  * Fix main window width
  * trivial: Update BRs to build in COPR
* Tue Sep 10 2019 dead_mozay@opensuse.org
- Update to version 0.0.1~git.20190904:
  * Update screenshots to include releases page as well
  * Revert "Tweak UI to take less horizontal space"
* Tue Sep  3 2019 dead_mozay@opensuse.org
- Update to version 0.0.1~git.20190830:
  * Add a screenshot
  * Tweak UI to take less horizontal space
* Fri Aug 30 2019 Dead Mozay <dead_mozay@opensuse.org>
- Change format version
* Wed Aug 28 2019 dead_mozay@opensuse.org
- Update to version git+20190827.d5014ed:
  * trivial: Style fixups
  * Always include config.h in C source files
  * Use SPDX-License-Identifier in all source files
  * trivial: Use symbolic icons for the device flags
  * Do not show an icon for registered
  * trivial: don't allow verify button to work on locked devices
  * Correct the messaging associated with pressing the verify button
  * trivial: cover the case of clicking a device with and then without vendor
  * trivial: add a .gitignore
  * trivial: Be clearer about version strings
* Wed Aug 28 2019 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
